==> haskell-lens-action-0.2.6-296-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-3Ku1YafkmfEBJcpFiQXPoc
key:                  lens-action-0.2.6-3Ku1YafkmfEBJcpFiQXPoc
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  a69f727e0772c590553c0957f41f633c
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-3Ku1YafkmfEBJcpFiQXPoc
depends:
    base-4.17.2.1 comonad-5.0.9-7Nx7TLF48pI5LjqSes8omR
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR mtl-2.2.2
    profunctors-5.6.3-7SwpvPUR3WDDKDPlUxhog4
    semigroupoids-6.0.1-6I5b3GpOwhwAglmgd4w9RR transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-action-0.2.6-319-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-CVMYK9kqdgG3WJx6qt51UQ
key:                  lens-action-0.2.6-CVMYK9kqdgG3WJx6qt51UQ
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  b6508ef56c5275cc176a58c2ee8048ec
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-CVMYK9kqdgG3WJx6qt51UQ
depends:
    base-4.17.2.1 comonad-5.0.9-69ztrEylAHVD4BHHoJEwKX
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb mtl-2.2.2
    profunctors-5.6.3-GJws21l5du15P9B6ShOpfs
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
